__package__ = 'dsocli.provider.template.local.v1'
from .main import get_default_spec
from .main import LocalTemplateProvider
